ByteInput class

Allows reading of data into.

Mixed-in types

Constructors

ByteInput(Uint8List _buffer)
ByteInput.fromBytes(List<int> bytes)
factory

Properties

buffer → Uint8List
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
offset ↔ int
getter/setter pair
remainingLength → int?
Should return the remaining length of the input data. If no information about the input length is available, null should be returned.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

assertEndOfDataReached([String message = '']) → void
Asserts if the end of data is reached or not
inherited
clone() → ByteInput
clone
override
hasBytes() → bool
returns true if there are bytes left to be read
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peekByte(int index) → int
Gives a peek of the byte of current index and does not increments the current index
override
peekBytes(int start, int length) → Uint8List
Gives a peek of the bytescurrentIndex, currentIndex + length Does not increments the current index
override
read() → int
Read a single byte from the input.
override
readBytes(int length) → Uint8List
Get the bytes from the current index to the length
override
resetOffset() → void
override
toHex() → String
Get the hex string of the buffer
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited