Output mixin

Allows writing of data.

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pushByte(int byte) → void
Write a single byte to the output.
toString() → String
A string representation of this object.
inherited
write(List<int> bytes) → void
Write to the output.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

byteOutput() → ByteOutput