ArrayCodec<A> class

Mixed-in types

Constructors

ArrayCodec(Codec<A> codec, int size)
const

Properties

codec → Codec<A>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
final

Methods

decode(Input input) → List<A>
override
encode(List<A> value) → Uint8List
Convert self to an owned vector.
inherited
encodeTo(List<A> value, Output output) → void
Convert self to a slice and append it to the destination.
override
isSizeZero() → bool
Is Size Zero
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeHint(List<A> value) → int
If possible give a hint of expected size of the encoding.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited