BTreeMapCodec<K, V> class

BTreeMap to encode/decode map of values

Mixed-in types

Constructors

BTreeMapCodec({required Codec<K> keyCodec, required Codec<V> valueCodec})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyCodec → Codec<K>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueCodec → Codec<V>
final

Methods

decode(Input input) → Map<K, V>
override
encode(Map<K, V> value) → Uint8List
Convert self to an owned vector.
inherited
encodeTo(Map<K, V> value, Output output) → void
Convert self to a slice and append it to the destination.
override
isSizeZero() → bool
Is Size Zero
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeHint(Map<K, V> value) → int
If possible give a hint of expected size of the encoding.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited