CompositeCodec class

Composite to encode/decode map of values

Mixed-in types

Constructors

CompositeCodec(Map<String, Codec> mappedCodec)
constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
mappedCodec → Map<String, Codec>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(Input input) → Map<String, dynamic>
Decodes the value from the Codec's input
override
encode(Map<String, dynamic> value) → Uint8List
Convert self to an owned vector.
inherited
encodeTo(Map<String, dynamic> value, Output output) → void
Encodes Composite of values.
override
isSizeZero() → bool
Is Size Zero
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeHint(Map<String, dynamic> value) → int
If possible give a hint of expected size of the encoding.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited