Result<R, E> class

Constructors

Result.err(E? errValue)
const
Result.ok(R? okValue)
const

Properties

errValue → E?
final
hashCode → int
The hash code for this object.
no setterinherited
isErr → bool
no setter
isOk → bool
no setter
okValue → R?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited