SetCodec class

Mixed-in types

Constructors

SetCodec(int bitLength, List<String> values)
const

Properties

bitLength → int
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>
final

Methods

decode(Input input) → List<String>
override
encode(List<String> value) → Uint8List
Convert self to an owned vector.
inherited
encodeTo(List<String> value, Output output) → void
Convert self to a slice and append it to the destination.
override
isSizeZero() → bool
Is Size Zero
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeHint(List<String> value) → int
If possible give a hint of expected size of the encoding.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited